==> breeze_update_3.6.05.tar.gz: manage/save_head.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 6/15/2007
// Added head_name and WHERE clause for saving different head content.
// Revised: 3/26/2010	ELL
// Redirected save to edit_head.php instead of returning to the main menu.
// Fixed bug with ecape codes.
// Revised: 10/12/2010	ELL
// Changed timestamping of `revised` field due to change from VARCHAR to DATETIME in table structure.
// Revised: 1/16/2012	ELL
// Added "Publish" button and changed "Save" button function to save to draft. Also added "Revert" so that draft can be discarded.
// Revised: 2/10/2012	ELL
// Added table prefix handling.
	
	include ("check_session.php");

	$head_name = $_POST['head_name'];
	$head_content = $_POST['textarea_head_content'];
	$head_content = addslashes($head_content);
	$save = $_POST['save'];
	$publish = $_POST['publish'];
	$revert = $_POST['revert'];
	
	if (!isset($save) && !isset($publish) && !isset($revert))	// Something went foobar.  Don't do anything and bale out.
		header("Location: index.php");
		
	if ($revert == "Revert")	// Discard draft and go back to last published head content.
	{
		$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$head_name' AND `source`=2";
		$result = mysql_query($query, $bwb_link);	
		header("Location: edit_head.php?head_name=$head_name");
		exit;
	}

	$today = date("Y-m-d H:i:s");
	
	// Whether saving draft of publishing, save latest revision to draft table.
	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$head_name' AND `source`=2";
	$result = mysql_query($query, $bwb_link);
	if (mysql_num_rows($result) > 0)	
		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_draft SET page_content='$head_content', revised='$today', `source`=2 WHERE page_name='$head_name'";
	else
		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='$head_name', page_content='$head_content', revised='$today', `source`=2";
	$result = mysql_query($query, $bwb_link);
	
	if ($publish == "Publish")	// Publish latest changes.
	{
		$query = "SELECT head_name FROM " . BWB_TABLE_PREFIX . "head WHERE head_name='$head_name'";
		$result = mysql_query($query, $bwb_link);
		if (mysql_num_rows($result) > 0)
			$query = "UPDATE " . BWB_TABLE_PREFIX . "head SET head_content='$head_content', revised='$today' WHERE head_name='$head_name'";
		else
			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head SET head_name='$head_name', head_content='$head_content', revised='$today'";
		$result = mysql_query($query, $bwb_link);
	}
	
	header("Location: edit_head.php?head_name=$head_name");
	
?>

==> breeze_update_4.0.01.tar.gz: manage/save_head.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 6/15/2007
// Added head_name and WHERE clause for saving different head content.
// Revised: 3/26/2010	ELL
// Redirected save to edit_head.php instead of returning to the main menu.
// Fixed bug with ecape codes.
// Revised: 10/12/2010	ELL
// Changed timestamping of `revised` field due to change from VARCHAR to DATETIME in table structure.
// Revised: 1/16/2012	ELL
// Added "Publish" button and changed "Save" button function to save to draft. Also added "Revert" so that draft can be discarded.
// Revised: 2/10/2012	ELL
// Added table prefix handling.
	
	include ("check_session.php");

	$head_name = $_POST['head_name'];
	$head_content = $_POST['textarea_head_content'];
	$head_content = addslashes($head_content);
	$save = $_POST['save'];
	$publish = $_POST['publish'];
	$revert = $_POST['revert'];
	
	if (!isset($save) && !isset($publish) && !isset($revert))	// Something went foobar.  Don't do anything and bale out.
		header("Location: index.php");
		
	if ($revert == "Revert")	// Discard draft and go back to last published head content.
	{
		$query = "DELETE FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$head_name' AND `source`=2";
		$cnt = $bwb_dbh->exec($query);	
		header("Location: edit_head.php?head_name=$head_name");
		exit;
	}

	$today = date("Y-m-d H:i:s");
	
	// Whether saving draft of publishing, save latest revision to draft table.
	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$head_name' AND `source`=2";
	$result = $bwb_dbh->query($query);
	if ($result->rowCount() > 0)	
		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_draft SET page_content='$head_content', revised='$today', `source`=2 WHERE page_name='$head_name'";
	else
		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='$head_name', page_content='$head_content', revised='$today', `source`=2";
	$cnt = $bwb_dbh->exec($query);
	
	if ($publish == "Publish")	// Publish latest changes.
	{
		$query = "SELECT head_name FROM " . BWB_TABLE_PREFIX . "head WHERE head_name='$head_name'";
		$result = $bwb_dbh->query($query);
		if ($result->rowCount() > 0)
			$query = "UPDATE " . BWB_TABLE_PREFIX . "head SET head_content='$head_content', revised='$today' WHERE head_name='$head_name'";
		else
			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "head SET head_name='$head_name', head_content='$head_content', revised='$today'";
		$cnt = $bwb_dbh->exec($query);
	}
	
	header("Location: edit_head.php?head_name=$head_name");
	
?>
